@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 describe WPScan::Finders::ThemeVersion::WooFrameworkMetaGenerator do
   subject(:finder) { described_class.new(theme) }
-  let(:theme)      { WPScan::Theme.new(slug, target) }
+  let(:theme)      { WPScan::Model::Theme.new(slug, target) }
   let(:target)     { WPScan::Target.new('http://wp.lab/') }
-  let(:fixtures)   { File.join(FINDERS_FIXTURES, 'theme_version', 'woo_framework_meta_generator') }
+  let(:fixtures)   { FINDERS_FIXTURES.join('theme_version', 'woo_framework_meta_generator') }
 
   before do
     expect(target).to receive(:content_dir).and_return('wp-content')
@@ -11,7 +13,7 @@ describe WPScan::Finders::ThemeVersion::WooFrameworkMetaGenerator do
 
   describe '#passive' do
     after do
-      stub_request(:get, target.url).to_return(body: File.read(File.join(fixtures, 'editorial-1.3.5.html')))
+      stub_request(:get, target.url).to_return(body: File.read(fixtures.join('editorial-1.3.5.html')))
 
       expect(finder.passive).to eql @expected
     end
@@ -28,7 +30,7 @@ describe WPScan::Finders::ThemeVersion::WooFrameworkMetaGenerator do
       let(:slug) { 'Editorial' }
 
       it 'return the expected version' do
-        @expected = WPScan::Version.new(
+        @expected = WPScan::Model::Version.new(
           '1.3.5',
           found_by: 'Woo Framework Meta Generator (Passive Detection)',
           confidence: 80
