@@ -1,6 +1,8 @@
+# frozen_string_literal: true
+
 $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
 
-require 'simplecov'
+require 'simplecov' # Used filters are in /.simplecov
 require 'rspec/its'
 require 'webmock/rspec'
 
@@ -9,16 +11,14 @@ if ENV['TRAVIS']
   SimpleCov.formatter = Coveralls::SimpleCov::Formatter
 end
 
-SimpleCov.start do
-  add_filter '/spec/'
-  add_filter 'helper'
-end
-
 # See http://betterspecs.org/
 RSpec.configure do |config|
   config.expect_with :rspec do |c|
     c.syntax = :expect
   end
+
+  # For --only-failures / --next-failure
+  config.example_status_persistence_file_path = '/tmp/rspec_examples.txt'
 end
 
 def redefine_constant(constant, value)
@@ -28,7 +28,7 @@ end
 
 # Dynamic Finders Helpers
 def df_expected_all
-  YAML.safe_load(File.read(File.join(DYNAMIC_FINDERS_FIXTURES, 'expected.yml')))
+  YAML.safe_load(File.read(DYNAMIC_FINDERS_FIXTURES.join('expected.yml')))
 end
 
 def df_tested_class_constant(type, finder_class, slug = nil)
@@ -47,6 +47,10 @@ def df_stubbed_response(fixture, finder_super_class)
   end
 end
 
+def vuln_api_data_for(path)
+  JSON.parse(File.read(FIXTURES.join('db', 'vuln_api', "#{path}.json")))
+end
+
 require 'wpscan'
 require 'shared_examples'
 
@@ -97,9 +101,10 @@ module WebMock
 end
 # rubocop:enabled all
 
-SPECS                    = Pathname.new(__FILE__).dirname.to_s
-FIXTURES                 = File.join(SPECS, 'fixtures')
-FINDERS_FIXTURES         = File.join(FIXTURES, 'finders')
-DYNAMIC_FINDERS_FIXTURES = File.join(FIXTURES, 'dynamic_finders')
+SPECS                    = Pathname.new(__FILE__).dirname
+FIXTURES                 = SPECS.join('fixtures')
+FINDERS_FIXTURES         = FIXTURES.join('finders')
+DYNAMIC_FINDERS_FIXTURES = FIXTURES.join('dynamic_finders')
+ERROR_404_URL_PATTERN    = %r{/[a-z\d]{7}\.html$}
 
-redefine_constant(:DB_DIR, File.join(FIXTURES, 'db'))
+redefine_constant(:DB_DIR, FIXTURES.join('db'))
